import { createWebHistory, createRouter } from 'vue-router'
import Layout from '@/layout'
import Layoutmb from "@/layoutmb";

/**
 * Note: 路由配置项
 *
 * hidden: true                     // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
 * alwaysShow: true                 // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 *                                  // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 *                                  // 若你想不管路由下面的 children 声明的个数都显示你的根路由
 *                                  // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * redirect: noRedirect             // 当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'               // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * query: '{"id": 1, "name": "ry"}' // 访问路由的默认传递参数
 * meta : {
    noCache: true                   // 如果设置为true，则不会被 <keep-alive> 缓存(默认 false)
    title: 'title'                  // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'                // 设置该路由的图标，对应路径src/assets/icons/svg
    breadcrumb: false               // 如果设置为false，则不会在breadcrumb面包屑中显示
    activeMenu: '/system/user'      // 当路由设置了该属性，则会高亮相对应的侧边栏。
  }
 */

// 公共路由
export const constantRoutes = [
  {
    path: "/redirect",
    component: Layout,
    hidden: true,
    children: [
      {
        path: "/redirect/:path(.*)",
        component: () => import("@/views/redirect/index.vue"),
      },
    ],
  },
  {
    path: "/login",
    component: () => import("@/views/login"),
    hidden: true,
  },
  {
    path: "/register",
    component: () => import("@/views/register"),
    hidden: true,
  },
  {
    path: "/:pathMatch(.*)*",
    component: () => import("@/views/error/404"),
    hidden: true,
  },
  {
    path: "/401",
    component: () => import("@/views/error/401"),
    hidden: true,
  },
  {
    path: "/work",
    component: () => import("@/views/screen"),
    hidden: true,
  },
  {
    path: "",
    component: Layout,
    hidden: true,
    redirect: "/task/list/1",
    children: [
      // {
      //     path: "/index",
      //     component: () =>
      //         import ("@/views/index"),
      //     name: "Index",
      //     meta: { title: "首页", icon: "dashboard", affix: true },
      // },
    ],
  },
  {
    path: "/task",
    component: Layout,
    hidden: true,
    redirect: "noredirect",
    children: [
      {
        path: "list/:status",
        component: () => import("@/views/task/list/index"),
        name: "tasklist",
        meta: { title: "任务列表", icon: "user" },
      },
      {
        path: "detail/:id",
        component: () => import("@/views/task/detail/index"),
        name: "taskdetail",
        meta: { title: "任务详情" },
      },
    ],
  },
  {
    path: "/detection",
    component: Layout,
    hidden: true,
    redirect: "noredirect",
    children: [
      {
        path: "list/:status",
        component: () => import("@/views/detection/list/index"),
        name: "detectionlist",
        meta: { title: "检测计划列表", icon: "user" },
      },
      {
        path: "detail/:id",
        component: () => import("@/views/detection/detail/index"),
        name: "detectiondetail",
        meta: { title: "检测计划详情", icon: "user" },
      },
    ],
  },
  {
    path: "/maintain",
    component: Layout,
    hidden: true,
    redirect: "noredirect",
    children: [
      {
        path: "list/:status",
        component: () => import("@/views/maintain/list/index"),
        name: "maintainlist",
        meta: { title: "养护计划列表", icon: "user" },
      },
      {
        path: "detail/:id",
        component: () => import("@/views/maintain/detail/index"),
        name: "maintaindetail",
        meta: {
          title: "养护计划详情",
          activeMenu: "/maintain/list/1",
        },
      },
    ],
  },
  {
    path: "/mb",
    component: Layoutmb,
    hidden: true,
    redirect: "/mb/home",
    children: [
      {
        path: "home",
        component: () => import("@/views/mb/home/index"),
        name: "mbhome",
        meta: { title: "首页", icon: "user" },
      },
      {
        path: "maintain",
        component: () => import("@/views/mb/maintain/index"),
        name: "mbmaintain",
        meta: { title: "养护计划", icon: "user" },
      },
      {
        path: "maintain/detail/:id",
        component: () => import("@/views/mb/maintain/detail/index"),
        name: "mbmaintaindetail",
        meta: { title: "养护计划详情", icon: "user" },
      },
      {
        path: "maintain/feedback/:id",
        component: () => import("@/views/mb/maintain/feedback/index"),
        name: "mbtaskfeedback",
        meta: { title: "养护计划反馈", icon: "user" },
      },
      {
        path: "detection",
        component: () => import("@/views/mb/detection/index"),
        name: "mbdetection",
        meta: { title: "检测计划", icon: "user" },
      },
      {
        path: "detection/detail/:id",
        component: () => import("@/views/mb/detection/detail/index"),
        name: "mbdetectiondetail",
        meta: { title: "检测计划详情", icon: "user" },
      },
      {
        path: "detection/feedback/:id",
        component: () => import("@/views/mb/detection/feedback/index"),
        name: "mbtaskdetection",
        meta: { title: "检测计划反馈", icon: "user" },
      },
      {
        path: "task",
        component: () => import("@/views/mb/task/index"),
        name: "mbtask",
        meta: { title: "工单", icon: "user" },
      },
      {
        path: "task/disposal",
        component: () => import("@/views/mb/task/disposal/index"),
        name: "mbtaskdisposal",
        meta: { title: "工单", icon: "user" },
      },
      {
        path: "task/detail/:id",
        component: () => import("@/views/mb/task/detail/index"),
        name: "mbtaskdetail",
        meta: { title: "热线工单详情", icon: "user" },
      },
      {
        path: "task/add",
        component: () => import("@/views/mb/task/add/index"),
        name: "mbtaskadd",
        meta: { title: "热线工单新增", icon: "user" },
      },
    ],
  },
  {
    path: "/user",
    component: Layout,
    hidden: true,
    redirect: "noredirect",
    children: [
      {
        path: "profile",
        component: () => import("@/views/system/user/profile/index"),
        name: "Profile",
        meta: { title: "个人中心", icon: "user" },
      },
    ],
  },
  {
    path: "/system/user-auth",
    component: Layout,
    hidden: true,
    children: [
      {
        path: "role/:userId(\\d+)",
        component: () => import("@/views/system/user/authRole"),
        name: "AuthRole",
        meta: { title: "分配角色", activeMenu: "/system/user" },
      },
    ],
  },
  {
    path: "/system/role-auth",
    component: Layout,
    hidden: true,
    children: [
      {
        path: "user/:roleId(\\d+)",
        component: () => import("@/views/system/role/authUser"),
        name: "AuthUser",
        meta: { title: "分配用户", activeMenu: "/system/role" },
      },
    ],
  },
  {
    path: "/system/dict-data",
    component: Layout,
    hidden: true,
    children: [
      {
        path: "index/:dictId(\\d+)",
        component: () => import("@/views/system/dict/data"),
        name: "Data",
        meta: { title: "字典数据", activeMenu: "/system/dict" },
      },
    ],
  },
  {
    path: "/system/facilities",
    component: Layout,
    hidden: true,
    children: [
      {
        path: "",
        component: () => import("@/views/system/facilities/index"),
        name: "facilitiesindex",
        meta: { title: "设施列表", activeMenu: "/system/facilities" },
      },
      {
        path: "detail/:id",
        component: () => import("@/views/system/facilities/detail"),
        name: "facilitiesdetail",
        meta: { title: "设施详请", activeMenu: "/system/facilities" },
      },
    ],
  },
  {
    path: "/monitor/job-log",
    component: Layout,
    hidden: true,
    children: [
      {
        path: "index",
        component: () => import("@/views/monitor/job/log"),
        name: "JobLog",
        meta: { title: "调度日志", activeMenu: "/monitor/job" },
      },
    ],
  },
  {
    path: "/tool/gen-edit",
    component: Layout,
    hidden: true,
    children: [
      {
        path: "index/:tableId(\\d+)",
        component: () => import("@/views/tool/gen/editTable"),
        name: "GenEdit",
        meta: { title: "修改生成配置", activeMenu: "/tool/gen" },
      },
    ],
  },
];

const router = createRouter({
    history: createWebHistory(),
    routes: constantRoutes,
    scrollBehavior(to, from, savedPosition) {
        if (savedPosition) {
            return savedPosition
        } else {
            return { top: 0 }
        }
    },
});

export default router;
